==> gtkmm-3.93.0.tar.xz: gtkmm-3.93.0/gdk/gdkmm.h <==
/*
 * gdkmm.h
 *
 * Copyright 2002 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef _GDKMM_GDKMM_H_
#define _GDKMM_GDKMM_H_

#include <gdkmm/types.h>
#include <gdkmm/window.h>
#include <gdkmm/pixbuf.h>
#include <gdkmm/pixbufanimation.h>
#include <gdkmm/pixbufformat.h>
#include <gdkmm/pixbufloader.h>
#include <gdkmm/applaunchcontext.h>
#include <gdkmm/clipboard.h>
#include <gdkmm/cursor.h>
#include <gdkmm/drawingcontext.h>
#include <gdkmm/events.h>
#include <gdkmm/frameclock.h>
#include <gdkmm/glcontext.h>
#include <gdkmm/rectangle.h>
#include <gdkmm/devicetool.h>
#include <gdkmm/display.h>
#include <gdkmm/displaymanager.h>
#include <gdkmm/seat.h>
#include <gdkmm/texture.h>
#include <gdkmm/monitor.h>
#include <gdkmm/general.h>
#include <gdkmm/contentformatsbuilder.h>

#endif /* _GDKMM_GDKMM_H_ */

==> gtkmm-3.95.1.tar.xz: gtkmm-3.95.1/gdk/gdkmm.h <==
/*
 * gdkmm.h
 *
 * Copyright 2002 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef _GDKMM_GDKMM_H_
#define _GDKMM_GDKMM_H_

#include <gdkmm/applaunchcontext.h>
#include <gdkmm/cairocontext.h>
#include <gdkmm/contentformatsbuilder.h>
#include <gdkmm/clipboard.h>
#include <gdkmm/cursor.h>
#include <gdkmm/devicepad.h>
#include <gdkmm/devicetool.h>
#include <gdkmm/devicewithpad.h>
#include <gdkmm/display.h>
#include <gdkmm/displaymanager.h>
#include <gdkmm/drop.h>
#include <gdkmm/events.h>
#include <gdkmm/frameclock.h>
#include <gdkmm/general.h>
#include <gdkmm/glcontext.h>
#include <gdkmm/gltexture.h>
#include <gdkmm/monitor.h>
#include <gdkmm/paintable.h>
#include <gdkmm/pixbuf.h>
#include <gdkmm/pixbufanimation.h>
#include <gdkmm/pixbufformat.h>
#include <gdkmm/pixbufloader.h>
#include <gdkmm/rectangle.h>
#include <gdkmm/seat.h>
#include <gdkmm/snapshot.h>
#include <gdkmm/surface.h>
#include <gdkmm/texture.h>
#include <gdkmm/types.h>

#endif /* _GDKMM_GDKMM_H_ */
